#
# spec file for package chmlib
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libchm0
Name:           chmlib
Version:        0.40
Release:        25.4
Summary:        A library for dealing with ITSS/CHM files
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            http://www.jedrea.com/chmlib/
Source0:        http://www.jedrea.com/chmlib/%{name}-%{version}.tar.bz2
Source2:        baselibs.conf
# backported from upstream
Patch1:         chmlib-0001-Patch-to-fix-integer-types-problem-by-Goswin-von-Bre.patch
# backported from upstream
Patch2:         chmlib-0002-Fix-for-extract_chmLib-confusing-empty-files-with-di.patch
# PATCH-FIX-UPSTREAM: https://github.com/jedwing/CHMLib/pull/10
Patch3:         chm_http-port-shortopt.patch
# PATCH-FIX-UPSTREAM: https://github.com/jedwing/CHMLib/pull/11
Patch4:         chm_http-bind-localhost.patch
# PATCH-FIX-UPSTREAM: https://github.com/jedwing/CHMLib/pull/12
Patch5:         chm_http-output-server-address.patch
# PATCH-FIX-UPSTREAM: https://github.com/jedwing/CHMLib/pull/17
Patch6:         chmlib-c99.patch
BuildRequires:  gcc-c++

%description
CHMLIB is a library for dealing with Microsoft ITSS/CHM format files.

%package -n %{lname}
Summary:        A library for dealing with ITSS/CHM files
Group:          System/Libraries
Obsoletes:      chmlib < %{version}-%{release}
Provides:       chmlib = %{version}-%{release}

%description -n %{lname}
CHMLIB is a library for dealing with Microsoft ITSS/CHM format files.

%package      devel
Summary:        Documentation and Headers for chmlib
Group:          System/Libraries
Requires:       %{lname} = %{version}

%description	devel
This package contains the headers and documentation for the chmlib API
that programmers will need to develop applications which use chmlib,
the software library for dealing with Microsoft ITSS/CHM format files.

%package        examples
Summary:        Example applications for chmlib
Group:          System/Libraries
Requires:       %{lname} = %{version}

%description	examples
This package contains examples built on chmlib which may be useful
to convert chm files from command line.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} -fstack-protector"
export CXXFLAGS="$CFLAGS"
export CXXCPP="g++ -E"
%configure \
	--disable-static \
	--disable-pread \
	--enable-examples
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license COPYING
%doc AUTHORS NEWS README
%{_libdir}/*.so.*

%files devel
%{_includedir}/chm_lib.h
%{_includedir}/lzx.h
%{_libdir}/*.so

%files examples
%{_bindir}/*

%changelog
* Thu Oct  5 2023 Dirk Müller <dmueller@suse.com>
- drop chmlib-0.39.diff - superseded by
  chmlib-0001-Patch-to-fix-integer-types-problem-by-Goswin-von-Bre.patch
- add
  chmlib-0001-Patch-to-fix-integer-types-problem-by-Goswin-von-Bre.patch,
  chmlib-0002-Fix-for-extract_chmLib-confusing-empty-files-with-di.patch,
  chm_http-port-shortopt.patch, chm_http-bind-localhost.patch,
  chm_http-output-server-address.patch, chmlib-c99.patch: restrict
  access to localhost to somewhat reduce reach
* Mon Jun 14 2021 Jan Engelhardt <jengelh@inai.de>
- Upgrade old specfile constructs.
- Remove --with-pic (no effect with --disable-static).
* Sun May 10 2015 mpluskal@suse.com
- Use url for source
- Cleanup spec file with spec-cleaner
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
- Implement shlib policy
* Sat Jul 25 2009 beineri@opensuse.org
- build examples to an -examples sub-package (bnc#488307)
* Sun May 24 2009 vuntz@novell.com
- Update to version 0.40:
  + minor bugfix release
  + fix a few bugs related to the example programs, including
    stability issues related to chm_http.
  + remove the bashisms from mozilla_helper.sh.
* Fri Feb 27 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Thu Feb  8 2007 dmueller@suse.de
- fix -devel requir'ing release number
* Mon Jan 29 2007 stbinner@suse.de
- update to version 0.39:
  * all of the dynamically-sized buffers which were allocated on
    the stack before have been changed to heap allocations. This
    circumvents some dangerous security flaws. (#239747)
* Wed Aug  9 2006 stbinner@suse.de
- update to version 0.38:
  * fix extract_chmLib directory traversal problem (#197808)
  * bugfix to allow successful reading of more chm files
* Sat Jun  3 2006 schwab@suse.de
- Port to all future systems.
* Mon May 22 2006 stbinner@suse.de
- Initial package of version 0.37.4
